xrdfit package
==============

xrdfit.plotting module
----------------------

.. automodule:: xrdfit.plotting
   :members:
   :undoc-members:
   :show-inheritance:

xrdfit.pv\_fit module
---------------------

.. automodule:: xrdfit.pv_fit
   :members:
   :undoc-members:
   :show-inheritance:

xrdfit.spectrum\_fitting module
-------------------------------

.. automodule:: xrdfit.spectrum_fitting
   :members:
   :undoc-members:
   :show-inheritance: